@@ -1,8 +1,4 @@
-{-# LANGUAGE CPP         #-}
-
-#if __GLASGOW_HASKELL__ >= 702
 {-# LANGUAGE Trustworthy #-}
-#endif
 
 {- |
 Module      : Data.UUID.Types
